// Copyright (c) 2010 Keith D Gregory, all rights reserved
package com.kdgregory.app.s3util.actions;

import java.awt.event.ActionEvent;
import java.util.List;

import javax.swing.AbstractAction;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import net.sf.s34j.rest.S3Factory;
import net.sf.swinglib.ClipManager;

import com.kdgregory.app.s3util.filelist.S3File;
import com.kdgregory.app.s3util.main.Concierge;


/**
 *  Copies the current file's URL to system clipboard; should only be
 *  enabled when there's a single selected file.
 */
public class EditCopyUrl
extends AbstractAction
{
    private static final long serialVersionUID = 1L;

    private Log _logger = LogFactory.getLog(this.getClass());

    private Concierge _concierge;


//----------------------------------------------------------------------------
//  Instance Variables and Constructor
//----------------------------------------------------------------------------

    public EditCopyUrl(Concierge concierge)
    {
        super("Copy URL");
        putValue(MNEMONIC_KEY, Integer.valueOf('U'));

        _concierge = concierge;
    }


//----------------------------------------------------------------------------
//  ActionListener
//----------------------------------------------------------------------------

    public void actionPerformed(ActionEvent ignored)
    {
        _logger.info("invoked");

        List<S3File> selection = _concierge.getMainFrame().getSelectedFiles();
        if (selection.size() == 0)
        {
            _logger.debug("nothing selected; ignored (but why was I enabled?");
            return;
        }

        // if more than one item selected, we'll punt and take first
        S3Factory s3Fact = _concierge.getS3Factory();
        String url = s3Fact.getUrl(
                        _concierge.getConfig().getAmazonBucketName(),
                        selection.get(0).getKey());
        _logger.debug("selected url: " + url);

        ClipManager.putString(url);
    }
}
