// Copyright (c) 2010 Keith D Gregory, all rights reserved
package com.kdgregory.app.s3util.actions;

import java.awt.event.ActionEvent;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.io.File;

import javax.swing.AbstractAction;
import javax.swing.KeyStroke;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.kdgregory.app.s3util.dialogs.DownloadDialogController;
import com.kdgregory.app.s3util.main.Concierge;
import com.kdgregory.app.s3util.s3ops.S3DownloadOp;


/**
 *  Initiates the download process, displaying a file chooser and handling
 *  its response.
 */
public class FileDownload
extends AbstractAction
{
    private static final long serialVersionUID = 1L;

    private Log _logger = LogFactory.getLog(this.getClass());

    private Concierge _concierge;
    private DownloadDialogController _dialogController;


    public FileDownload(Concierge concierge)
    {
        super("Download Selected...");
        putValue(MNEMONIC_KEY, Integer.valueOf('D'));
        putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_O, InputEvent.CTRL_MASK));

        _concierge = concierge;
        _dialogController = new DownloadDialogController(concierge);
        setEnabled(false);
    }


//----------------------------------------------------------------------------
//  ActionListener
//----------------------------------------------------------------------------

    public void actionPerformed(ActionEvent evt)
    {
        _logger.info("invoked");
        File selected = _dialogController.show();
        _logger.debug("selected directory: " + selected);
        if (selected != null)
        {
            new S3DownloadOp(
                    _concierge,
                    _concierge.getMainFrame().getSelectedFiles(),
                    selected,
                    _dialogController.getFlatten())
            .start();
        }
    }
}
