// Copyright (c) 2010 Keith D Gregory, all rights reserved
package com.kdgregory.app.s3util.s3ops;

import java.io.File;
import java.io.FileOutputStream;
import java.util.List;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import net.sf.s34j.rest.S3Object;

import com.kdgregory.app.s3util.filelist.S3File;
import com.kdgregory.app.s3util.main.Concierge;


/**
 *  Downloads one or more files from S3 into a specified directory,
 *  optionally flattening the directory structure..
 */
public class S3DownloadOp
extends AbstractS3Op<Object>
{
    private Log _logger = LogFactory.getLog(this.getClass());

    private List<S3File> _files;
    private File _dest;
    private boolean _flatten;

    public S3DownloadOp(Concierge concierge, List<S3File> files,
                        File dest, boolean flatten)
    {
        super(concierge, "Downloading file(s)");
        _files = files;
        _dest = dest;
        _flatten = flatten;
    }


//----------------------------------------------------------------------------
//  Operation
//----------------------------------------------------------------------------

    @Override
    protected Object performOperation()
    throws Exception
    {
        _logger.debug("starting request");
        for (S3File file : _files)
        {
            updateProgressMonitor(file.getS3Path());
            download(file);
        }
        _logger.debug("request complete");
        return null;
    }


//----------------------------------------------------------------------------
//  Internals
//----------------------------------------------------------------------------

    // performs the actual download operation; exists as separate method
    // to reduce clutter
    private void download(S3File file)
    throws Exception
    {
        _logger.debug(file.getKey());
        S3Object obj = createS3Object(file.getKey());

        File destDir = _dest;
        String s3Path = file.getS3Path();
        if (!_flatten && !StringUtils.isEmpty(s3Path))
        {
            destDir = new File(_dest, s3Path);
            if (!destDir.mkdirs())
                throw new RuntimeException("unable to create directories: " + s3Path);
        }

        File localFile = new File(destDir, file.getFile().getName());
        FileOutputStream out = new FileOutputStream(localFile);
        try
        {
            obj.readToStream(out);
        }
        finally
        {
            IOUtils.closeQuietly(out);
        }
    }
}